
#ifndef _C145_eq7237_
#define _C145_eq7237_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F1998_27373(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
extern void EIF_Minit7237(void);

#ifdef __cplusplus
}
#endif

#endif
